@@ -20,6 +20,8 @@ import sys
 
 SKIP = {
     # Access Denied
+    "sql/account_ecosystem_derived/ecosystem_client_id_lookup_v1/query.sql",
+    "sql/account_ecosystem_derived/desktop_clients_daily_v1/query.sql",
     "sql/activity_stream/impression_stats_flat/view.sql",
     "sql/activity_stream/tile_id_types/view.sql",
     "sql/monitoring/deletion_request_volume_v1/query.sql",
@@ -60,6 +62,7 @@ SKIP = {
     "sql/apple_app_store/metrics_by_web_referrer/query.sql",
     "sql/apple_app_store/metrics_total/query.sql",
     "sql/monitoring/telemetry_distinct_docids_v1/query.sql",
+    "sql/revenue_derived/client_ltv_normalized/query.sql",
     # Already exists (and lacks an "OR REPLACE" clause)
     "sql/org_mozilla_firefox_derived/clients_first_seen_v1/init.sql",
     "sql/org_mozilla_firefox_derived/clients_last_seen_v1/init.sql",
