@@ -24,9 +24,11 @@ from bigquery_etl.query_scheduling.utils import (
 
 AIRFLOW_TASK_TEMPLATE = "airflow_task.j2"
 QUERY_FILE_RE = re.compile(
-    r"^.*/([a-zA-Z0-9_]+)/([a-zA-Z0-9_]+)_(v[0-9]+)/(?:query\.sql|part1\.sql)$"
+    r"^.*/([a-zA-Z0-9_]+)/([a-zA-Z0-9_]+)_(v[0-9]+)/"
+    r"(?:query\.sql|part1\.sql|script\.sql)$"
 )
 DEFAULT_PROJECT = "moz-fx-data-shared-prod"
+DEFAULT_DESTINATION_TABLE_STR = "use-default-destination-table"
 
 
 class TaskParseException(Exception):
@@ -151,6 +153,7 @@ class Task:
     priority: Optional[int] = None
     referenced_tables: Optional[List[Tuple[str, str]]] = attr.ib(None)
     allow_field_addition_on_date: Optional[str] = attr.ib(None)
+    destination_table: Optional[str] = attr.ib(default=DEFAULT_DESTINATION_TABLE_STR)
 
     @owner.validator
     def validate_owner(self, attribute, value):
@@ -202,6 +205,14 @@ class Task:
             if self.task_name is None:
                 self.task_name = f"{self.dataset}__{self.table}__{self.version}"
                 self.validate_task_name(None, self.task_name)
+
+            if self.destination_table == DEFAULT_DESTINATION_TABLE_STR:
+                self.destination_table = f"{self.table}_{self.version}"
+
+            if self.destination_table is None and self.sql_file_path is None:
+                raise ValueError(
+                    "One of destination_table or sql_file_path must be specified"
+                )
         else:
             raise ValueError(
                 "query_file must be a path with format:"
@@ -274,6 +285,20 @@ class Task:
         task.sql_file_path = os.path.dirname(query_file)
         return task
 
+    @classmethod
+    def of_script(cls, query_file, metadata=None, dag_collection=None):
+        """
+        Create task that schedules the corresponding script in Airflow.
+
+        Raises FileNotFoundError if no metadata file exists for query.
+        If `metadata` is set, then it is used instead of the metadata.yaml
+        file that might exist alongside the query file.
+        """
+        task = cls.of_query(query_file, metadata, dag_collection)
+        task.sql_file_path = query_file
+        task.destination_table = None
+        return task
+
     def _get_referenced_tables(self):
         """
         Perform a dry_run to get tables the query depends on.
